package Crypt::OpenSSL3::BigNum::Context;
$Crypt::OpenSSL3::BigNum::Context::VERSION = '0.001';
use strict;
use warnings;

use Crypt::OpenSSL3;

1;

# ABSTRACT: A context for complex calculations on Big Numbers

__END__

=pod

=encoding UTF-8

=head1 NAME

Crypt::OpenSSL3::BigNum::Context - A context for complex calculations on Big Numbers

=head1 VERSION

version 0.001

=head1 METHODS

=head2 new

=head2 secure_new

=head1 AUTHOR

Leon Timmermans <fawaka@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2025 by Leon Timmermans.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
